import 'dart:convert';
import 'package:http/http.dart';
import 'package:dio/dio.dart' as dio;

class ApiError {
  String? message;
  String? type;
  int? code;

  ApiError({
    this.message,
    this.type,
    this.code,
  });

  @override
  String toString() {
    return '$type($code): $message';
  }

  ApiError.fromResponse(Response response) {
    final body = jsonDecode(response.body);

    code = response.statusCode;
    message = body['message'] ??
        body['status_text'] ??
        body['error_description'] ??
        'UNEXPECTED_SERVER_ERROR';

    if (body['errors'] != null && body['errors'].isNotEmpty) {
      message = body['errors'][0]['message'];
    }

    type = body['message'];
  }

  ApiError.fromDioResponse(dio.Response response) {
    var body = json.decode(response.data);

    code = response.statusCode;
    message = body['message'] ??
        body['status_text'] ??
        body['error_description'] ??
        'UNEXPECTED_SERVER_ERROR';
    type = body['message'];
  }
}
