import '../../mixins/localized.mixin.dart';
import '../entity.base.dart';

class Award extends Entity with Localized {
  final String name;
  final String nameEs;
  final String nameCa;

  final List<int> thresholds;

  Award({
    String? id,
    String? createdAt,
    String? updatedAt,
    required this.name,
    required this.nameEs,
    required this.nameCa,
    this.thresholds = const [],
  }) : super(id, createdAt, updatedAt);

  getNextThreshold(int score) {
    for (final threshold in thresholds) {
      if (score < threshold) return threshold;
    }

    return 0;
  }

  factory Award.fromJson(Map<String, dynamic> json) {
    final thresholds = List.from(json['thresholds']).map((e) {
      if (e is int) return e;
      if (e is String) return int.tryParse(e) ?? 0;
      return 0;
    }).toList();

    return Award(
      id: '${json['id']}',
      createdAt: json['created'],
      updatedAt: json['updated'],
      name: json['name'],
      nameEs: json['name_es'],
      nameCa: json['name_ca'],
      thresholds: thresholds,
    );
  }
}
