import 'package:rec_api_dart/src/entities/entity.base.dart';

class Campaign extends Entity {
  static String STATUS_CREATED = 'created';
  static String STATUS_ACTIVE = 'active';
  static String STATUS_FINISHED = 'finished';

  DateTime? initDate;
  DateTime? endDate;

  num min;
  num max;
  int balance;
  int version;
  num percent;

  String? name;
  String? description;
  String? code;
  String? videoPromoUrl;
  String? imageUrl;
  String? urlTos;
  String? promoUrl;
  String status;

  bool bonusEnabled;
  bool endingAlert;

  Campaign({
    String? id,
    String? createdAt,
    String? updatedAt,
    required this.status,
    this.initDate,
    this.endDate,
    this.min = 0,
    this.max = 0,
    this.balance = 0,
    this.name,
    this.description,
    this.code,
    this.videoPromoUrl,
    this.imageUrl,
    this.promoUrl,
    this.urlTos,
    this.percent = 0,
    this.version = 1,
    this.bonusEnabled = false,
    this.endingAlert = false,
  }) : super(id, createdAt, updatedAt);

  bool get isActive {
    return status == Campaign.STATUS_ACTIVE;
  }

  bool isFinished() {
    if (endDate == null) return false;

    var currentDate = DateTime.now();
    var diff = endDate!.difference(currentDate);
    return diff.inSeconds <= 0;
  }

  bool isStarted() {
    var currentDate = DateTime.now();
    var diff = initDate!.difference(currentDate);
    return diff.inSeconds <= 0;
  }

  @override
  Map<String, dynamic> toJson() {
    return {
      'id': id,
      'created_at': createdAt.toIso8601String(),
      'updated_at': updatedAt.toIso8601String(),
      'init_date': initDate!.toIso8601String(),
      'end_date': endDate!.toIso8601String(),
      'min': min,
      'max': max,
      'balance': balance,
      'name': name,
      'video_promo_url': videoPromoUrl,
      'image_url': imageUrl,
    };
  }

  factory Campaign.fromJson(Map<String, dynamic> json) {
    return Campaign(
      id: '${json['id']}',
      createdAt: json['created'],
      updatedAt: json['updated'],
      initDate: DateTime.parse(json['init_date']),
      endDate: DateTime.parse(json['end_date']),
      min: json['min'] ?? 0,
      max: json['max'] ?? 0,
      balance: json['balance'] ?? 0,
      name: json['name'],
      description: json['description'],
      code: json['code'],
      videoPromoUrl: json['video_promo_url'],
      imageUrl: json['image_url'],
      promoUrl: json['promo_url'],
      urlTos: json['url_tos'],
      version: json['version'],
      status: json['status'] ?? Campaign.STATUS_CREATED,
      percent: json['redeemable_percentage'] ?? 0,
      bonusEnabled: json['bonus_enabled'] ?? false,
      endingAlert: json['ending_alert'] ?? false,
    );
  }
}
