import 'package:rec_api_dart/src/entities/entity.base.dart';
import 'package:rec_api_dart/src/mixins/localized.mixin.dart';

enum ProductType {
  consuming,
  producing;

  get name {
    switch (this) {
      case ProductType.consuming:
        return 'consuming';
      case ProductType.producing:
        return 'producing';
    }
  }

  get apiPath {
    switch (this) {
      case ProductType.consuming:
        return 'consuming_products';
      case ProductType.producing:
        return 'producing_products';
    }
  }
}

class Product extends Entity with Localized {
  static String STATUS_REVIEWED = 'reviewed';
  static String STATUS_CREATED = 'created';

  String name;
  String nameEs;
  String nameCa;

  Product({
    String? id,
    String? createdAt,
    String? updatedAt,
    required this.name,
    required this.nameEs,
    required this.nameCa,
  }) : super(id, createdAt, updatedAt);

  bool get hasValues => name.isNotEmpty && nameEs.isNotEmpty && nameCa.isNotEmpty;

  factory Product.fromJson(Map<String, dynamic> json) {
    return Product(
      id: '${json['id']}',
      createdAt: json['created'],
      updatedAt: json['updated'],
      name: json['name'] ?? '',
      nameEs: json['name_es'] ?? '',
      nameCa: json['name_ca'] ?? '',
    );
  }

  @override
  Map<String, dynamic> toJson() {
    return {};
  }
}
