import 'package:rec_api_dart/src/entities/entity.base.dart';
import 'package:rec_api_dart/src/entities/transactions/pay_in_info.dart';
import 'package:rec_api_dart/src/entities/transactions/pay_out_info.dart';

import 'currency.ent.dart';

class TransactionType {
  static String OUT = 'out';
  static String IN = 'in';
  static String RECHARGE = 'recharge';
}

class TransactionMethod {
  static String REC = 'rec';
  static String EUR = 'eur';
}

class Transaction extends Entity {
  String? service;
  String? method;
  String? status;
  String? ip;
  String? hasDataIn;
  String? currency;
  String? type;
  String? paymentOrderId;

  int? bonificationCampaignId;
  int amount;
  int? total;
  int scale;
  int? maxNotificationTries;
  int? notificationTries;

  late double scaledAmount;
  double? variableFee;
  double? fixedFee;

  bool? internal;
  bool? deleted;
  bool? notified;
  bool isBonification;

  PayOutInfo? payOutInfo;
  PayInInfo? payInInfo;
  TransactionType? internalType;
  List<String> refundsIds;

  /// The parent transaction (only refund transactions will contain this)
  Transaction? refundParentTransaction;

  Transaction({
    String? id,
    String? createdAt,
    String? updatedAt,
    required this.amount,
    required this.scale,
    this.service,
    this.method,
    this.status,
    this.ip,
    this.hasDataIn,
    this.currency,
    this.type,
    this.total,
    this.paymentOrderId,
    this.variableFee,
    this.fixedFee,
    this.maxNotificationTries,
    this.notificationTries,
    this.internal,
    this.deleted,
    this.notified,
    this.payOutInfo,
    this.payInInfo,
    this.refundsIds = const [],
    this.refundParentTransaction,
    this.isBonification = false,
    this.bonificationCampaignId,
  }) : super(id, createdAt, updatedAt) {
    scaledAmount = Currency.amountScaled(amount, scale);
  }

  String? getType() => type;
  bool isType(String type) => this.type == type;
  bool isOut() => isType(TransactionType.OUT);
  bool isIn() => isType(TransactionType.IN);
  bool isRefund() => refundParentTransaction != null;
  bool hasPayInInfo() => payInInfo != null;
  bool hasPayOutInfo() => payOutInfo != null;
  bool hasRefundIds() => refundsIds.isNotEmpty;

  String? getConcept() {
    if (isOut()) return payOutInfo!.concept;
    if (isIn()) return payInInfo!.concept;

    return 'NO_CONCEPT';
  }

  factory Transaction.fromJson(Map<String, dynamic> json) {
    final refundParentTransaction = json['refund_parent_transaction'] != null
        ? Transaction.fromJson(json['refund_parent_transaction'])
        : null;

    return Transaction(
      id: json['id'],
      createdAt: json['created'],
      updatedAt: json['updated'],
      service: json['service'],
      method: json['method'],
      status: json['status'],
      ip: json['ip'],
      hasDataIn: json['has_data_in'],
      currency: json['currency'],
      paymentOrderId: json['payment_order_id'],
      type: json['type'],
      amount: double.parse('${json['amount']}').toInt(),
      total: double.parse('${json['total']}').toInt(),
      scale: json['scale'],
      variableFee: (json['variable_fee'] ?? 0).toDouble(),
      fixedFee: (json['fixed_fee'] ?? 0).toDouble(),
      maxNotificationTries: json['max_notification_tries'],
      notificationTries: json['notification_tries'],
      internal: json['internal'],
      deleted: json['deleted'],
      notified: json['notified'],
      isBonification: json['is_bonification'] ?? false,
      bonificationCampaignId: json['bonification_campaign_id'],
      refundsIds: List<String>.from(json['refund_txs'] ?? []),
      refundParentTransaction: refundParentTransaction,
      payOutInfo: json['pay_out_info'] != null ? PayOutInfo.fromJson(json['pay_out_info']) : null,
      payInInfo: json['pay_in_info'] != null ? PayInInfo.fromJson(json['pay_in_info']) : null,
    );
  }
}
