import 'package:http/http.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/env.base.dart';
import 'package:rec_api_dart/src/interceptors/user_token_interceptor.dart';
import 'package:rec_api_dart/src/interfaces/account_campaign_list.dart';
import 'package:rec_api_dart/src/services/base_service.dart';

import '../entities/account_campaign.ent.dart';

/// This service is in charge of all requests related to [AccountCampaign]
///
/// * **Authentication Required** - the user must be authenticated
class AccountCampaignsService extends ServiceBase {
  AccountCampaignsService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  /// List all [AccountCampaign]
  Future<AccountCampaign> getOne(String id) {
    final uri = ApiPaths.accountCampaigns.append(id).asUri(env.API_URL);

    return this.get(uri).then((res) {
      return AccountCampaign.fromJson(res['data']);
    });
  }

  /// List all [AccountCampaign] for the authenticated user
  Future<AccountCampaignList> list({
    bool onlyActive = true,
  }) {
    final uri = ApiPaths.accountCampaigns.withQueryParams({
      'only_active_campaigns': (onlyActive ? 1 : 0).toString(),
    }).asUri(env.API_URL);

    return this.get(uri).then(_mapCampaigns);
  }

  AccountCampaignList _mapCampaigns(
    Map<String, dynamic> resp,
  ) {
    return AccountCampaignList.fromJson(resp['data']);
  }
}
