import 'package:http/http.dart';
import 'package:rec_api_dart/rec_api_dart.dart';

class ProductsService extends ServiceBase {
  ProductsService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  /// List all [Product]s for the authenticated user
  Future<ApiListResponse<Product>> list({String? status, String? search}) {
    final uri = ApiPaths.searchProducts.withQueryParams({
      'limit': '100',
      if (search != null && search.isNotEmpty) 'search': search,
      if (status != null && status.isNotEmpty) 'status': status,
    }).asUri(env.API_URL);

    return this.get(uri).then(_mapProducts);
  }

  Future addProduct(String name, ProductType? type) {
    final uri = ApiPaths.products.asUri(env.API_URL);

    return this.post(uri, {
      'name': name,
      'type': type?.name,
    });
  }

  Future removeProduct(String accountId, String id, ProductType? type) {
    final uri =
        ApiPaths.accounts.append(accountId).append(type!.apiPath).append(id).asUri(env.API_URL);

    return this.delete(uri);
  }

  ApiListResponse<Product> _mapProducts(
    Map<String, dynamic> data,
  ) {
    return ApiListResponse.fromJson(
      data['data'],
      mapper: (el) => Product.fromJson(el),
    );
  }
}
