import 'package:flutter_test/flutter_test.dart';
import 'package:rec_api_dart/src/entities/main.dart';

void main() {
  test('Account works with data', () async {
    var account = Account(
      name: 'Test',
    );
    expect(account.name, 'Test');
  });

  test('Account works fromJson', () async {
    var account = Account.fromJson({
      'name': 'test',
      'wallets': [
        {'currency': Currency.rec.name, 'balance': 0},
        {'currency': Currency.eur.name, 'balance': 0},
      ],
      'street': 'aaa',
      'address_number': 'aaa',
      'zip': 'aaa',
      'level': Map<String, dynamic>.from({'code': 'KYC2'}),
      'schedule': '',
    });
    expect(account.name, 'test');
  });


  test('Account.fullPhone works with prefix and phone', () async {
    var account = Account.fromJson({
      'name': 'test',
      'wallets': [
        {'currency': Currency.rec.name, 'balance': 0},
        {'currency': Currency.eur.name, 'balance': 0},
      ],
      'street': 'aaa',
      'address_number': 'aaa',
      'zip': 'aaa',
      'level': Map<String, dynamic>.from({'code': 'KYC2'}),
      'schedule': '',
      'prefix': '34',
      'phone': '666666666'
    });
    expect(account.fullPhone, '+34 666666666');
  });

  test('Account.fullPhone works with only phone', () async {
    var account = Account.fromJson({
      'name': 'test',
      'wallets': [
        {'currency': Currency.rec.name, 'balance': 0},
        {'currency': Currency.eur.name, 'balance': 0},
      ],
      'street': 'aaa',
      'address_number': 'aaa',
      'zip': 'aaa',
      'level': Map<String, dynamic>.from({'code': 'KYC2'}),
      'schedule': '',
      'phone': '666666666'
    });
    expect(account.fullPhone, '666666666');
  });
}
