import 'package:flutter_test/flutter_test.dart';
import 'package:rec_api_dart/src/entities/transactions/transaction.ent.dart';

void main() {
  test('Transaction in is treated as such', () async {
    final txIn = Transaction.fromJson({
      'type': TransactionType.IN,
      'amount': 1000,
      'total': 1000,
      'scale': 8,
      'method': TransactionMethod.REC,
      'pay_in_info': {
        'concept': 'in test concept',
        'name_sender': 'test',
        'amount': 1000,
        'received': 1000,
      },
    });
    expect(txIn.getType(), TransactionType.IN);
    expect(txIn.isType(TransactionType.IN), true);
    expect(txIn.isIn(), true);
    expect(txIn.isOut(), false);
    expect(txIn.hasPayInInfo(), true);
    expect(txIn.hasPayOutInfo(), false);
    expect(txIn.getConcept(), 'in test concept');
  });

  test('Transaction out is treated as such', () async {
    final txIn = Transaction.fromJson({
      'type': TransactionType.OUT,
      'amount': 1000,
      'total': 1000,
      'scale': 8,
      'method': TransactionMethod.REC,
      'pay_out_info': {
        'concept': 'out test concept',
        'name_receiver': 'test',
        'amount': 1000,
      },
    });
    expect(txIn.getType(), TransactionType.OUT);
    expect(txIn.isType(TransactionType.OUT), true);
    expect(txIn.isIn(), false);
    expect(txIn.isOut(), true);
    expect(txIn.hasPayInInfo(), false);
    expect(txIn.hasPayOutInfo(), true);
    expect(txIn.getConcept(), 'out test concept');
  });

  test('Transaction scaledAmount is calculated correctly', () async {
    final txIn = Transaction.fromJson({
      'type': TransactionType.OUT,
      'amount': 100000000,
      'total': 100000000,
      'scale': 8,
      'method': TransactionMethod.REC,
      'pay_out_info': {
        'concept': 'out test concept',
        'name_receiver': 'test',
        'amount': 100000000,
      },
    });

    expect(txIn.scaledAmount, 1.00);
  });
}
