import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:rec_api_dart/src/api_paths.dart';
import 'package:rec_api_dart/src/auth.dart';
import 'package:rec_api_dart/src/entities/configuration_settings.ent.dart';
import 'package:rec_api_dart/src/services/public/app_service.dart';
import 'package:http/http.dart' as http;

import '../../http_stubs.dart';
import '../../mocks/configuration_settings_mock.dart';
import '../../mocks/storage_mock.dart';
import '../../test_env.dart';
import 'login_service.mocks.dart';

void main() {
  final mockStorage = StorageMock();
  Auth.storage = mockStorage;

  test('AppService.login calls correctly and returns', () async {
    final client = MockClient();
    stubPost(
      client,
      ApiPaths.token.asUri(env.API_URL),
      http.Response(
        '{"access_token": "test", "refresh_token": "test", "expires_in": 3600}',
        200,
      ),
    );

    final service = AppService(
      env: env,
      client: client,
    );

    expect(
      await service.getAppToken(),
      {"access_token": "test", "refresh_token": "test", "expires_in": 3600},
    );
  });

  test('AppService.getConfigurationSettings calls correctly and returns', () async {
    final client = MockClient();
    stubGet(
      client,
      ApiPaths.configurationSettings.asUri(env.API_URL),
      http.Response(
        json.encode(ConfigurationSettingsMock.configurationSettingsResponse),
        200,
      ),
    );

    final service = AppService(env: env, client: client);

    expect(await service.getConfigurationSettings(), isInstanceOf<ConfigurationSettings>());
  });
}
